@@ -10,7 +10,7 @@ _DT_ALMOST_MAX = datetime.max - timedelta(1.0)
 class Provider(BaseProvider):
     """Implement default user agent provider for Faker."""
 
-    user_agents: ElementsType = (
+    user_agents: ElementsType[str] = (
         "chrome",
         "firefox",
         "internet_explorer",
@@ -18,7 +18,9 @@ class Provider(BaseProvider):
         "safari",
     )
 
-    windows_platform_tokens: ElementsType = (
+    # source
+    # https://en.wikipedia.org/wiki/Microsoft_Windows
+    windows_platform_tokens: ElementsType[str] = (
         "Windows 95",
         "Windows 98",
         "Windows 98; Win 9x 4.90",
@@ -32,13 +34,16 @@ class Provider(BaseProvider):
         "Windows NT 6.1",
         "Windows NT 6.2",
         "Windows NT 10.0",
+        "Windows NT 11.0",
     )
 
-    linux_processors: ElementsType = ("i686", "x86_64")
+    linux_processors: ElementsType[str] = ("i686", "x86_64")
 
-    mac_processors: ElementsType = ("Intel", "PPC", "U; Intel", "U; PPC")
+    mac_processors: ElementsType[str] = ("Intel", "PPC", "U; Intel", "U; PPC")
 
-    android_versions: ElementsType = (
+    # source
+    # https://en.wikipedia.org/wiki/Android_version_history
+    android_versions: ElementsType[str] = (
         "1.0",
         "1.1",
         "1.5",
@@ -101,11 +106,17 @@ class Provider(BaseProvider):
         "9",
         "10",
         "11",
+        "12",
+        "12.1",
+        "13",
+        "14",
     )
 
-    apple_devices: ElementsType = ("iPhone", "iPad")
+    apple_devices: ElementsType[str] = ("iPhone", "iPad")
 
-    ios_versions: ElementsType = (
+    # sources
+    # https://en.wikipedia.org/wiki/IOS_version_history
+    ios_versions: ElementsType[str] = (
         "3.1.3",
         "4.2.1",
         "5.1.1",
@@ -115,9 +126,23 @@ class Provider(BaseProvider):
         "9.3.6",
         "10.3.3",
         "10.3.4",
+        "11.4.1",
+        "12.4.4",
         "12.4.8",
+        "13.5.1",
         "14.2",
         "14.2.1",
+        "14.8.1",
+        "15.8.2",
+        "16.7.6",
+        "17.1",
+        "17.1.1",
+        "17.1.2",
+        "17.2",
+        "17.2.1",
+        "17.3",
+        "17.3.1",
+        "17.4",
     )
 
     def mac_processor(self) -> str:
@@ -145,7 +170,7 @@ class Provider(BaseProvider):
         bld: str = self.lexify(self.numerify("##?###"), string.ascii_uppercase)
         tmplt: str = "({0}) AppleWebKit/{1} (KHTML, like Gecko)" " Chrome/{2}.0.{3}.0 Safari/{4}"
         tmplt_ios: str = "({0}) AppleWebKit/{1} (KHTML, like Gecko)" " CriOS/{2}.0.{3}.0 Mobile/{4} Safari/{1}"
-        platforms: ElementsType = (
+        platforms: ElementsType[str] = (
             tmplt.format(
                 self.linux_platform_token(),
                 saf,
@@ -187,7 +212,7 @@ class Provider(BaseProvider):
 
     def firefox(self) -> str:
         """Generate a Mozilla Firefox web browser user agent string."""
-        ver: ElementsType = (
+        ver: ElementsType[str] = (
             (
                 f"Gecko/{self.generator.date_time_between(datetime(2011, 1, 1), _DT_ALMOST_MAX)} "
                 f"Firefox/{self.generator.random.randint(4, 15)}.0"
@@ -206,7 +231,7 @@ class Provider(BaseProvider):
         saf: str = "{}.{}".format(self.generator.random.randint(531, 536), self.generator.random.randint(0, 2))
         bld: str = self.lexify(self.numerify("##?###"), string.ascii_uppercase)
         bld2: str = self.lexify(self.numerify("#?####"), string.ascii_lowercase)
-        platforms: ElementsType = (
+        platforms: ElementsType[str] = (
             tmplt_win.format(
                 self.windows_platform_token(),
                 self.generator.locale().replace("_", "-"),
@@ -257,7 +282,7 @@ class Provider(BaseProvider):
             " Mobile/8B{5} Safari/6{6}"
         )
         locale: str = self.generator.locale().replace("_", "-")
-        platforms: ElementsType = (
+        platforms: ElementsType[str] = (
             tmplt_win.format(self.windows_platform_token(), saf, ver, saf),
             tmplt_mac.format(
                 self.mac_platform_token(),
